function results =SGboots(Y,mh,itb)
%% PURPOSE: Get the SGboots test
% --------------------------------------------------------
% USAGE: 
% where: Y  = Rx1 vector with quantitative data.
%        mh = Rxm matrix with m-sourrounding (use m_hist0.m)
%        itb = number boots
% --------------------------------------------------------
%  RETURNS: results.sgboots - the value of the SGboots statistic
%           results.pvalue - the p-value
% --------------------------------------------------------
% References: 
% Lopez FA, Matilla M, Mur J and M Ruiz (2010) A Non-Parametric Spatial Independence Test
% Using Symbolic Entropy, Regional Science and Urban Economic. 40, 106-115
%
% Ruiz M, Lpez FA, A Pez. (2010) Testing for spatial association of qualitative 
% data using symbolic dynamics. Journal of Geographical Systems. 12 (3) 281-309
%
% ?Lpez FA, Matilla M, Mur J, Ruiz M and Pez A (2015) A note on the SG(m) test, 
% Journal of Geographical Systems (forthcoming)
%
% --------------------------------------------------------
% SEE ALSO: SG.m
% --------------------------------------------------------
%
% written by:
%
% Fernando A. Lopez Hernandez
% Facultad de C.C. de la Empresa
% Dpto. Metodos Cuantitativos e Informaticos
% Universidad Politecnica de Cartagena
% e-mail: fernando.lopez@upct.es

R=length(Y);
sg=SG(Y,mh);
psg=zeros(itb,1);
% Note: use parfor if you have parallel computing
for i=1:itb
    YP=Y(randperm(R));
    b=SG(YP,mh);
    psg(i,1)=b.sg;
end
pseudovalue=sum(psg(:,1)>sg.sg)/(itb+1);
results.sgboots=sg.sg;
results.pvalue=pseudovalue;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%     Print Rresults
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    fprintf(1,'\n')
    fprintf(1,'  Sample size               (R) = %9.0f\n',R)
    fprintf(1,'  Size of m-surrounding     (m) = %9.0f\n',size(mh,2))
    fprintf(1,'  Number of boots           (B) = %9.0f\n',itb)
    fprintf(1,'\n')
    fprintf(1,' SGboot Test for spatial dependence \n');
    fprintf(1,'  Test         Value    p-value \n');
    fprintf(1,'  SGboot  =%9.2f',sg.sg);fprintf(1,'  %9.4f \n',pseudovalue);
end